==> mupad-1.4.2.tgz: mupad/share/mmg/include/kernel/MSW_int.h <==
/*
 * kg, 5.12.95
 *
 * MSW_int.h -- Interface-Routinen des Kerns zum Windows-DDE-Server
 */

#ifndef _MSW_INT_H_
#define _MSW_INT_H_

#ifdef DOS_FILENAMES
#include "MMMstora.h"
#include "MPR_prot.h"
#include "MCT_iost.h"
#else
#include "MMMstorage.h"
#include "MPR_protocol.h"
#include "MCT_iostream.h"
#endif

#define MSWC_NO_MEM_ERROR_TEXT "Not enough memory."

/* MSW_get_cmd -- sorgt dafuer, dass das naechste Kommando vom Client
 * geliefert wird. Der Kommando-String wird dann mittels MSW_fgets
 * erfragt. (Hierin ist die 'main event loop' implementiert!) */
void MSW_get_cmd(void);

/* MSW_get_dbg_cmd -- liefert aehnlich wie MSW_get_cmd naechstes Kommando
 * vom Client, nur dass als Eingabe ein Debug-Kommando erwartet wird. */
void MSW_get_dbg_cmd(void);

/* MSW_fgets -- liefert Eingabe-String vom Client oder von File.
 * Parameter a'la fgets. Ist file = stdin, so wird eine Eingabe vom
 * Client erwartet. */
char *MSW_fgets(char *s, int n, MCLT_iostream &file);

/* MSW_exit -- sorgt fuer korrekten Programmabbruch des Servers.
 * s gibt Statuswert an, 0 = fehlerfreier Abbruch */
void MSW_exit(int s);

/* MSW_fatal -- Fehlermeldung und Abbruch nach fatalem Fehler. */
void MSW_fatal(char *s);

/* MSW_message -- Fehlermeldung nach internem Fehler, falls MEV_error
 * nicht verwendet werden kann. */
void MSW_message(char *s);

/* MSW_pr_puts -- Ausagbe einer typisierten Meldung, wird in
 * MPR_protocol.c verwendet, um MPR_putstring zu implementieren.
 * Die Typen der Meldungen sind in MPR_protocol.h definiert. */
void MSW_pr_puts(MPRTtype t, char *s);

/* MSW_puts -- untypisierte Ausagbe, wird bei Kommunikation mit
 * naiven DDE-Clients verwendet (CMD-Protokoll). */
void MSW_puts(char *s);

/* MSW_query_cmd -- interaktive Abfrage einer MuPAD-Eingabe nach 'input'.
 * p ist der Prompt, zurueckgeliefert werden muss ein Pointer auf einen
 * Buffer, der einen 0-terminierten C-String enthaelt. Der Buffer wird
 * vom Kern nicht weiter verwaltet. */
char *MSW_query_cmd(char *p);

/* MSW_query_text -- interaktive Abfrage einer Text-Eingabe nach 'textinput'.
 * Ansonsten wie MSW_query_cmd zu benutzen. */
char *MSW_query_text(char *p);

/* MSW_handle_events -- arbeitet evtl. anstehende Windows-Events waehrend
 * laengerer Rechnungen ab, wird von MAMMUT und PARI regelmaessig aufgerufen.
 * Dies ist notwendig, damit andere Applikationen auch mal 'and die Reihe
 * kommen' und nicht haengen. */
void MSW_handle_events(void);

/* MSW_alarm -- installiert die Alarm-Funktion tf, die in s Sekunden 1mal
 * aufgerufen werden soll. Ein bestehender Alarm wird geloescht. Ist s = 0,
 * so wird nur ein ggf. bestehender Alarm geloescht.
 * Zurueckgeliefert werden sollte eigentlich die Zeit bis zum geloeschten
 * Alarm, zZt. aber immer 0. */
int MSW_alarm(int s, void (*tf)(void));

/* MSW_clock -- liefert User-Zeit des Task's in Millisekunden. */
long MSW_clock(void);

/* MSW_get_tmp_filename -- liefert in Puffer buff Name fuer temporaeres 
 * File. Die Pufferlaenge ist len. nr dient zur Unterscheidung mehrerer
 * temporaerer Files und wird in den Namen integriert. */
char *MSW_get_tmp_filename(char *buff, int len, short nr);

/* MSW_open_plot_file -- liefert Fileptr fuer temp. File, das zur Uebertragung
 * von Plot-Daten ans Frontend benutzt wird. (Nur eine Kruecke)
 * Der Name des Files wird in den Buffer buff kopiert. */
int MSW_open_plot_file(char *buff, MCLT_iostream &file);

/* MSW_close_plot_file -- schliesst temp. File zur Uebertragung von Plot-Daten,
 * damit das Frontend das File zum Lesen oeffnen kann. */
void MSW_close_plot_file(void);

/* MSW_plot_file_name -- liefert Zeiger auf String mit Namen des Files zur 
 * Uebertragung von Plot-Daten. */
char *MSW_plot_file_name(void);

/* MSW_is_registered -- liefert TRUE falls der Benutzer registriert ist. */
int MSW_is_registered(void);

/* MSW_register -- registriert Benutzer
 * Liefert FALSE, falls der Benutzer nicht registriert werden konnte. */
int MSW_register(char *name);

/* MSW_register_campus -- registriert Campus
 * Liefert FALSE, falls der Campus nicht registriert werden konnte. */
int MSW_register_campus(char *name);

/* MSW_user_init_file -- liefert Name des User-Init-File
 * Liefert NULL, falls der Benutzer kein User-Init-File angegeben hat. */
char *MSW_user_init_file(void);

#endif /* ! _MSW_INT_H_ */

==> mupad-2.0.0.tgz: mupad/share/mmg/include/kernel/MSW_int.h <==
/*
 * kg, 5.12.95
 *
 * MSW_int.h -- Interface-Routinen des Kerns zu Win32
 */

#ifndef _MSW_INT_H_
#define _MSW_INT_H_

#ifdef DOS_FILENAMES
#include "MMMstora.h"
#include "MPR_prot.h"
#include "MCT_iost.h"
#else
#include "MMMstorage_lean.h"
#include "MPR_protocol.h"
#include "MCT_iostream.h"
#endif

/* MSW_init -- initializes Win32-specific stuff which is independent from
 * actual frame implementation */
void MSW_init();

/* MSW_exit -- sorgt fuer korrekten Programmabbruch des Servers.
 * s gibt Statuswert an, 0 = fehlerfreier Abbruch */
void MSW_exit(int s);

/* MSW_cleanup -- interne Routine fuer Cleanup bei exit unter Windows. */
void MSW_cleanup(int s);

/* MSW_fatal -- Fehlermeldung und Abbruch nach fatalem Fehler. */
void MSW_fatal(char *s);

/* MSW_message -- Fehlermeldung nach internem Fehler, falls MEV_error
 * nicht verwendet werden kann. */
void MSW_message(char *s);

/* MSW_message_box -- show message in dialog box or write it to file in 
 * batch mode. */
void MSW_message_box(char *s, unsigned int type);

/* MSW_handle_events -- arbeitet evtl. anstehende Windows-Events waehrend
 * laengerer Rechnungen ab, wird von MAMMUT und PARI regelmaessig aufgerufen.
 * Dies ist notwendig, damit andere Applikationen auch mal 'and die Reihe
 * kommen' und nicht haengen. */
void MSW_handle_events(bool main_loop, bool wait);

/* MSW_alarm -- installiert die Alarm-Funktion tf, die in s Sekunden 1mal
 * aufgerufen werden soll. Ein bestehender Alarm wird geloescht. Ist s = 0,
 * so wird nur ein ggf. bestehender Alarm geloescht.
 * Zurueckgeliefert werden sollte eigentlich die Zeit bis zum geloeschten
 * Alarm, zZt. aber immer 0. */
int MSW_alarm(int s, void (*tf)(void));

/* MSW_clock -- liefert User-Zeit des Task's in Millisekunden. */
long MSW_clock(void);

/* MSW_get_tmp_filename -- liefert in Puffer buff Name fuer temporaeres
 * File. Die Pufferlaenge ist len. nr dient zur Unterscheidung mehrerer
 * temporaerer Files und wird in den Namen integriert. */
char *MSW_get_tmp_filename(char *buff, int len, short nr);

/* MSW_is_registered -- liefert TRUE falls der Benutzer registriert ist. */
int MSW_is_registered(void);

/* MSW_register -- registriert Benutzer
 * Liefert FALSE, falls der Benutzer nicht registriert werden konnte. */
int MSW_register(char *name);

/* MSW_register_campus -- registriert Campus
 * Liefert FALSE, falls der Campus nicht registriert werden konnte. */
int MSW_register_campus(char *name);

/* MSW_open_plot_file -- liefert Fileptr fuer temp. File, das zur Uebertragung
 * von Plot-Daten ans Frontend benutzt wird.
 * Der Name des Files wird in den Buffer buff kopiert. */
int MSW_open_plot_file(char *buff, MCLT_iostream &file);

/* MSW_close_plot_file -- schliesst temp. File zur Uebertragung von Plot-Daten,
 * damit das Frontend das File zum Lesen oeffnen kann. */
void MSW_close_plot_file(void);

/* MSW_user_init_file -- liefert Name des User-Init-File
 * Liefert NULL, falls der Benutzer kein User-Init-File angegeben hat. */
char *MSW_user_init_file(void);

/* MSW_lib_path -- liefert Pfad der Standard-Library
 * Liefert 0, falls der Benutzer keinen Pfad angegeben hat. */
int MSW_lib_path(char* buff, int buff_len);

#endif /* ! _MSW_INT_H_ */
